.. index::
   single: pviews; --help

.. _pviews_script:

.. autoprogram:: pyramid.scripts.pviews:PViewsCommand.parser
    :prog: pviews

.. seealso:: :ref:`displaying_matching_views` and :ref:`running-pscripts`.
